@@ -1,5 +1,5 @@
 from graphgallery.backend import *
-from graphgallery.utils.type_check import *
+from graphgallery.data_type import *
 
 # modules
 from graphgallery import nn
@@ -7,10 +7,10 @@ from graphgallery import utils
 from graphgallery import sequence
 from graphgallery import data
 from graphgallery import backend
-from graphgallery import transforms
+from graphgallery import functional
 
 
-__version__ = '0.4.2'
+__version__ = '0.5.0'
 
 __all__ = ['graphgallery', 'nn', 'utils', 'sequence', 'data',
-           'backend', 'transforms', '__version__']
+           'backend', 'functional', '__version__']
