@@ -1,5 +1,8 @@
+import torch
 import tensorflow as tf
 
+__all__ = ['set_memory_growth', 'empty_cache']
+
 
 def set_memory_growth() -> None:
     """Set if memory growth should be enabled for ALL `PhysicalDevice`.
@@ -20,3 +23,8 @@ def set_memory_growth() -> None:
         except RuntimeError as e:
             # Memory growth must be set before GPUs have been initialized
             print(e)
+
+
+def empty_cache() -> None:
+    torch.cuda.empty_cache()
+    tf.keras.backend.clear_session()
