@@ -1,4 +1,7 @@
 from graphgallery.data.dataset import Dataset
 from graphgallery.data.planetoid import Planetoid
 from graphgallery.data.npz_dataset import NPZDataset
-from graphgallery.data.graph import Graph, Basegraph
+from graphgallery.data.graph import Graph
+from graphgallery.data.multigraph import MultiGraph
+from graphgallery.data.base_graph import BaseGraph
+
