@@ -1,14 +1,14 @@
 import os
-import logging
 import errno
 import os.path as osp
 from tensorflow.keras.utils import get_file
+from typing import List
 
-from graphgallery import is_list_like
-from typing import List, Tuple, Union
+from graphgallery import is_listlike
 
-def download_file(raw_paths: Union[List[str], Tuple[str]], 
-                  urls: Union[List[str], Tuple[str]]):
+
+def download_file(raw_paths: List[str],
+                  urls: List[str]) -> None:
 
     last_except = None
     for filename, url in zip(raw_paths, urls):
@@ -21,14 +21,14 @@ def download_file(raw_paths: Union[List[str], Tuple[str]],
         raise last_except
 
 
-def files_exist(files: Union[List[str], Tuple[str]]):
-    if is_list_like(files):
+def files_exist(files: List[str]) -> bool:
+    if is_listlike(files):
         return len(files) != 0 and all([osp.exists(f) for f in files])
     else:
         return osp.exists(files)
 
 
-def makedirs(path: str):
+def makedirs(path: str) -> None:
     try:
         os.makedirs(osp.expanduser(osp.normpath(path)))
     except OSError as e:
@@ -36,10 +36,9 @@ def makedirs(path: str):
             raise e
 
 
-def makedirs_from_path(path: str, verbose: bool=True):
-    file_dir = osp.split(osp.realpath(path))[0]
+def makedirs_from_filename(filename: str, verbose: bool = True) -> None:
+    file_dir = osp.split(osp.realpath(filename))[0]
     if not osp.exists(file_dir):
         makedirs(file_dir)
         if verbose:
-            logging.log(logging.WARNING,
-                        f"Creating a folder in {path}.")
+            print(f"Creating folder in {filename}.", file=sys.stderr)
