@@ -1,7 +1,7 @@
 import numpy as np
 
 
-def softmax(x: np.ndarray, axis=-1)->np.ndarray:
+def softmax(x: np.ndarray, axis: int = -1) -> np.ndarray:
     """Numpy version of Softmax activation function
 
     Parameters
