@@ -4,20 +4,20 @@ import tensorflow as tf
 
 from tensorflow.keras.utils import Sequence as tf_Sequence
 from torch.nn import Module
-
 from functools import partial
 
-from graphgallery import transforms as T
+from graphgallery import functional as F
+
 
 class Sequence(tf_Sequence):
 
     def __init__(self, *args, **kwargs):
         device = kwargs.pop('device', 'cpu')
+        escape = kwargs.pop('escape', None)
         super().__init__(*args, **kwargs)
-        self.astensor = partial(T.astensor, device=device)
-        self.astensors = partial(T.astensors, device=device)
+        self.astensor = partial(F.astensor, device=device, escape=escape)
+        self.astensors = partial(F.astensors, device=device, escape=escape)
         self.device = device
-        
 
     def __len__(self):
         raise NotImplementedError
@@ -30,4 +30,3 @@ class Sequence(tf_Sequence):
 
     def _shuffle_batches(self):
         ...
-        
\ No newline at end of file
