@@ -7,11 +7,17 @@ def tqdm_clear(*args, **kwargs):
 
 
 def tqdm(*args, **kwargs):
+    """decorator of tqdm, to avoid some errors if tqdm 
+    terminated unexpectedly
+
+    Returns
+    -------
+    an decorated `tqdm` class
+    """
 
-    #     get_ipython().events.register('post_execute', tqdm_clear)
     if hasattr(tqdm_base, '_instances'):
         for instance in list(tqdm_base._instances):
             tqdm_base._decr_instances(instance)
     return tqdm_base(*args, **kwargs)
 
-tqdm.__doc__ = tqdm_base.__doc__ + tqdm_base.__init__.__doc__
\ No newline at end of file
+tqdm.__doc__ = tqdm_base.__doc__ + tqdm_base.__init__.__doc__
